@@ -2,13 +2,13 @@
 # -*- coding: utf-8 -*-
 # Author: Barney Walker <barney@labstep.com>
 from deprecated import deprecated
+from labstep.entities.experimentLink.repository import newExperimentLink
 from labstep.generic.entityPrimary.model import EntityPrimary
 from labstep.generic.entityList.model import EntityList
 from labstep.entities.experimentProtocol.model import ExperimentProtocol
-from labstep.entities.experimentMaterial.model import ExperimentMaterial
-from labstep.entities.experimentTable.model import ExperimentTable
 from labstep.entities.experimentSignature.model import ExperimentSignature
-from labstep.service.helpers import getTime
+from labstep.service.helpers import getTime, handleDate
+from labstep.constants import UNSPECIFIED
 
 
 class Experiment(EntityPrimary):
@@ -33,7 +33,7 @@ class Experiment(EntityPrimary):
             self.root_experiment = ExperimentProtocol(
                 data['root_experiment'], user)
 
-    def edit(self, name=None, entry=None, started_at=None, extraParams={}):
+    def edit(self, name=UNSPECIFIED, entry=UNSPECIFIED, started_at=UNSPECIFIED, extraParams={}):
         """
         Edit an existing Experiment.
 
@@ -81,6 +81,56 @@ class Experiment(EntityPrimary):
 
         return experimentRepository.editExperiment(self, deleted_at=getTime())
 
+    def lock(self):
+        """
+        Lock an Experiment. Once locked, only owners can unlock.
+
+        Example
+        -------
+        ::
+
+            my_experiment = user.getExperiment(17000)
+            my_experiment.lock()
+        """
+        import labstep.entities.experiment.repository as experimentRepository
+        return experimentRepository.editExperiment(self, extraParams={'locked_at': getTime()})
+
+    def unlock(self):
+        """
+        Unlock a locked Experiment. Can only be done with owner permission.
+
+        Example
+        -------
+        ::
+
+            my_experiment = user.getExperiment(17000)
+            my_experiment.lock()
+            my_experiment.unlock()
+        """
+        import labstep.entities.experiment.repository as experimentRepository
+        return experimentRepository.editExperiment(self, extraParams={'locked_at': None})
+
+    def complete(self, date=UNSPECIFIED):
+        """
+        Marks an experiment as complete.
+
+        Parameters
+        ----------
+        date (str)
+            Optionally specify a particular datetime it was completed.
+            Date format 'YYYY-MM-DD HH:MM:SS'
+
+        Example
+        -------
+        ::
+
+            my_experiment = user.getExperiment(17000)
+            my_experiment.complete()
+        """
+        import labstep.entities.experiment.repository as experimentRepository
+        return experimentRepository.editExperiment(self,
+                                                   extraParams={'ended_at': handleDate(date) if date is not UNSPECIFIED else getTime()})
+
     def getEntry(self):
         """
         Returns a JSON document representing the entry for the experiment.
@@ -94,6 +144,9 @@ class Experiment(EntityPrimary):
         """
         import labstep.generic.entity.repository as entityRepository
 
+        if hasattr(self, 'root_experiment') is False:
+            self.update()
+
         return entityRepository.getEntity(
             self.__user__, ExperimentProtocol, self.root_experiment.id
         ).state
@@ -159,11 +212,11 @@ class Experiment(EntityPrimary):
         self,
         fieldName,
         fieldType="default",
-        value=None,
-        date=None,
-        number=None,
-        unit=None,
-        filepath=None,
+        value=UNSPECIFIED,
+        date=UNSPECIFIED,
+        number=UNSPECIFIED,
+        unit=UNSPECIFIED,
+        filepath=UNSPECIFIED,
         extraParams={},
     ):
         """
@@ -244,7 +297,7 @@ class Experiment(EntityPrimary):
         exp = self.__user__.getExperiment(self.id)
         return EntityList(exp.signatures, ExperimentSignature, self.__user__)
 
-    def addSignature(self, statement=None, lock=False):
+    def addSignature(self, statement=UNSPECIFIED, lock=False):
         """
         Add a signature to experiment
 
@@ -281,7 +334,7 @@ class Experiment(EntityPrimary):
 
         return experimentSignatureRequestRepository.getExperimentSignatureRequests(self.__user__, self.id)
 
-    def requestSignature(self, user_id, message=None):
+    def requestSignature(self, user_id, message=UNSPECIFIED):
         """
         Request a signature from another user in the workspace
 
@@ -320,11 +373,11 @@ class Experiment(EntityPrimary):
 
     def addMaterial(
         self,
-        name=None,
-        amount=None,
-        units=None,
-        resource_id=None,
-        resource_item_id=None,
+        name=UNSPECIFIED,
+        amount=UNSPECIFIED,
+        units=UNSPECIFIED,
+        resource_id=UNSPECIFIED,
+        resource_item_id=UNSPECIFIED,
         extraParams={},
     ):
         """
@@ -422,7 +475,7 @@ class Experiment(EntityPrimary):
         """
         return self.root_experiment.getTables()
 
-    def addTable(self, name=None, data=None):
+    def addTable(self, name=UNSPECIFIED, data=UNSPECIFIED):
         """
         Add a new table to an Experiment.
 
@@ -465,7 +518,7 @@ class Experiment(EntityPrimary):
         """
         return self.root_experiment.addTable(name=name, data=data)
 
-    def addFile(self, filepath=None, rawData=None):
+    def addFile(self, filepath=UNSPECIFIED, rawData=UNSPECIFIED):
         """
         Add a file to an experiment entry.
         (Only use for files to be embedded in the body of the entry)
@@ -491,6 +544,30 @@ class Experiment(EntityPrimary):
         """
         return self.root_experiment.addFile(filepath, rawData)
 
+    def getComments(self, count=100):
+        """
+        Retrieve the Comments attached to this Labstep Entity.
+
+        Returns
+        -------
+        List[:class:`~labstep.entities.comment.model.Comment`]
+            List of the comments attached.
+
+        Example
+        -------
+        ::
+
+            entity = user.getExperiment(17000)
+            comments = entity.getComments()
+            comments[0].attributes()
+        """
+        import labstep.entities.comment.repository as commentRepository
+
+        if hasattr(self, 'thread_ids') is False:
+            self.update()
+
+        return commentRepository.getComments(self, count, extraParams={'parent_thread_id': self.thread_ids})
+
     def getFiles(self):
         """
         Returns a list of the files in a experiment entry.
@@ -510,6 +587,33 @@ class Experiment(EntityPrimary):
         """
         return self.root_experiment.getFiles()
 
+    def addExperimentLink(self, experiment_id):
+        """
+        Link this experiment to a previous experiment.
+        """
+        return newExperimentLink(self.__user__, src_experiment_id=self.id, dest_experiment_id=experiment_id)
+
+    def getExperimentLinks(self, direction='forward'):
+        """
+        Returns a list of experiments that the current experiment references (direction = "forward")
+        or a list of experiments that reference the current experiment (direction = "backwards")
+
+        Returns
+        -------
+        List[:class:`~labstep.experimentLink.ExperimentLink`]
+            List of linked experiments.
+
+        Example
+        -------
+        ::
+
+            experiment = user.getExperiment(17000)
+            experimentLinks = experiment.getExperimentLinks(direction="backwards")
+        """
+        import labstep.entities.experimentLink.repository as experimentLinkRepository
+
+        return experimentLinkRepository.getExperimentLinks(self.__user__, self.id, direction=direction)
+
     def export(self, path):
         """
         Export the experiment to the directory specified. 
