@@ -11,6 +11,7 @@ from labstep.entities.experimentProtocol.model import ExperimentProtocol
 from labstep.entities.resource.model import Resource
 from labstep.entities.resourceItem.model import ResourceItem
 from labstep.entities.file.model import File
+from labstep.constants import UNSPECIFIED
 
 
 def getDataFields(entity, count=1000, extraParams={}):
@@ -43,17 +44,17 @@ def addDataFieldTo(
     entity,
     fieldName,
     fieldType="default",
-    value=None,
-    date=None,
-    number=None,
-    unit=None,
-    filepath=None,
+    value=UNSPECIFIED,
+    date=UNSPECIFIED,
+    number=UNSPECIFIED,
+    unit=UNSPECIFIED,
+    filepath=UNSPECIFIED,
     extraParams={},
 ):
-    if filepath is not None:
+    if filepath is not UNSPECIFIED:
         fileId = fileRepository.newFile(entity.__user__, filepath).id
     else:
-        fileId = None
+        fileId = UNSPECIFIED
 
     params = {
         "metadata_thread_id": entity.metadata_thread["id"],
@@ -70,7 +71,7 @@ def addDataFieldTo(
     return entityRepository.newEntity(entity.__user__, ExperimentDataField, params)
 
 
-def editDataField(dataField, fieldName=None, value=None, extraParams={}):
+def editDataField(dataField, fieldName=UNSPECIFIED, value=UNSPECIFIED, extraParams={}):
     params = {
         "label": handleString(fieldName),
         "value": handleString(value),
