@@ -10,13 +10,14 @@ from labstep.entities.experimentTable.model import ExperimentTable
 from labstep.entities.experimentTimer.model import ExperimentTimer
 import labstep.entities.file.repository as fileRepository
 import labstep.entities.experimentMaterial.repository as experimentMaterialRepository
+from labstep.constants import UNSPECIFIED
 
 
 class ExperimentProtocol(Entity):
     __entityName__ = "experiment"
 
     def edit(
-        self, name=None, body=None, started_at=None, ended_at=None, extraParams={}
+        self, name=UNSPECIFIED, body=UNSPECIFIED, started_at=UNSPECIFIED, ended_at=UNSPECIFIED, extraParams={}
     ):
         """
         Edit an existing ExperimentProtocol.
@@ -107,11 +108,11 @@ class ExperimentProtocol(Entity):
 
     def addMaterial(
         self,
-        name=None,
-        amount=None,
-        units=None,
-        resource_id=None,
-        resource_item_id=None,
+        name=UNSPECIFIED,
+        amount=UNSPECIFIED,
+        units=UNSPECIFIED,
+        resource_id=UNSPECIFIED,
+        resource_item_id=UNSPECIFIED,
         extraParams={},
     ):
         """
@@ -176,7 +177,7 @@ class ExperimentProtocol(Entity):
         steps = [{"experiment_id": self.id}] * N
         return entityRepository.newEntities(self.__user__, ExperimentStep, steps)
 
-    def addTable(self, name=None, data=None):
+    def addTable(self, name=UNSPECIFIED, data=UNSPECIFIED):
         """
         Add a new table to a Protocol within an Experiment.
 
@@ -245,7 +246,7 @@ class ExperimentProtocol(Entity):
         steps = self.experiment_steps
         return EntityList(steps, ExperimentStep, self.__user__)
 
-    def addTimer(self, name=None, hours=None, minutes=None, seconds=None):
+    def addTimer(self, name=UNSPECIFIED, hours=UNSPECIFIED, minutes=UNSPECIFIED, seconds=UNSPECIFIED):
         """
         Add a new timer to a Protocol within an Experiment.
 
@@ -354,11 +355,11 @@ class ExperimentProtocol(Entity):
         self,
         fieldName,
         fieldType="default",
-        value=None,
-        date=None,
-        number=None,
-        unit=None,
-        filepath=None,
+        value=UNSPECIFIED,
+        date=UNSPECIFIED,
+        number=UNSPECIFIED,
+        unit=UNSPECIFIED,
+        filepath=UNSPECIFIED,
         extraParams={},
     ):
         """
@@ -412,7 +413,7 @@ class ExperimentProtocol(Entity):
             extraParams=extraParams,
         )
 
-    def addFile(self, filepath=None, rawData=None):
+    def addFile(self, filepath=UNSPECIFIED, rawData=UNSPECIFIED):
         """
         Add a file to an Experiment Protocol.
 
@@ -460,7 +461,7 @@ class ExperimentProtocol(Entity):
         files = self.files
         return EntityList(files, File, self.__user__)
 
-    def export(self, rootPath, folderName=None):
+    def export(self, rootPath, folderName=UNSPECIFIED):
         import labstep.entities.experimentProtocol.repository as experimentProtocolRepository
         return experimentProtocolRepository.exportExperimentProtocol(self, rootPath, folderName=folderName)
 
