@@ -4,12 +4,13 @@
 
 from labstep.generic.entity.model import Entity
 from labstep.service.helpers import dataTableToDataFrame
+from labstep.constants import UNSPECIFIED
 
 
 class ExperimentTable(Entity):
     __entityName__ = "experiment-table"
 
-    def edit(self, name=None, data=None):
+    def edit(self, name=UNSPECIFIED, data=UNSPECIFIED):
         """
         Edit an existing Experiment Table.
 
