@@ -4,12 +4,13 @@
 
 from labstep.generic.entity.model import Entity
 from labstep.service.helpers import dataTableToDataFrame
+from labstep.constants import UNSPECIFIED
 
 
 class ProtocolTable(Entity):
     __entityName__ = "protocol-table"
 
-    def edit(self, name=None, data=None, extraParams={}):
+    def edit(self, name=UNSPECIFIED, data=UNSPECIFIED, extraParams={}):
         """
         Edit an existing Protocol Table.
 
