@@ -4,6 +4,7 @@
 
 from labstep.entities.resource.model import Resource
 import labstep.generic.entity.repository as entityRepository
+from labstep.constants import UNSPECIFIED
 
 
 def getResource(user, resource_id):
@@ -11,14 +12,14 @@ def getResource(user, resource_id):
 
 
 def getResources(
-    user, count=100, search_query=None, tag_id=None, extraParams={}
+    user, count=100, search_query=UNSPECIFIED, tag_id=UNSPECIFIED, extraParams={}
 ):
     params = {"search_query": search_query,
               "tag_id": tag_id, **extraParams}
     return entityRepository.getEntities(user, Resource, count, params)
 
 
-def newResource(user, name, resource_category_id=None, extraParams={}):
+def newResource(user, name, resource_category_id=UNSPECIFIED, extraParams={}):
     params = {
         "name": name,
         "template_id": resource_category_id,
@@ -29,9 +30,9 @@ def newResource(user, name, resource_category_id=None, extraParams={}):
 def editResource(
 
     resource,
-    name=None,
-    deleted_at=None,
-    resource_category_id=None,
+    name=UNSPECIFIED,
+    deleted_at=UNSPECIFIED,
+    resource_category_id=UNSPECIFIED,
     extraParams={},
 ):
     params = {
