@@ -6,6 +6,7 @@ from labstep.generic.entityWithSharing.model import EntityWithSharing
 from labstep.service.helpers import getTime
 from labstep.entities.resourceTemplate.model import ResourceTemplate
 from labstep.entities.resourceItem.model import ResourceItem
+from labstep.constants import UNSPECIFIED
 
 
 class ResourceCategory(EntityWithSharing):
@@ -24,7 +25,7 @@ class ResourceCategory(EntityWithSharing):
 
     __entityName__ = "resource"
 
-    def edit(self, name=None, extraParams={}):
+    def edit(self, name=UNSPECIFIED, extraParams={}):
         """
         Edit an existing ResourceCategory.
 
