@@ -5,6 +5,7 @@
 import json
 from pathlib import Path
 from pathvalidate import sanitize_filepath
+from labstep.entities.export.model import Export
 from labstep.generic.entityList.model import EntityList
 from labstep.service.config import configService
 from labstep.service.helpers import (
@@ -44,7 +45,11 @@ def getEntity(user, entityClass, id, isDeleted="both", useGuid=False):
 def getEntities(user, entityClass, count, filterParams={}):
     countParameter = min(
         count, 50) if count is not UNSPECIFIED else UNSPECIFIED
-    searchParams = {"search": 1, "cursor": -1, "count": countParameter}
+
+    if entityClass == Export:
+        searchParams = {"cursor": -1, "count": countParameter}
+    else:
+        searchParams = {"search": 1, "cursor": -1, "count": countParameter}
 
     params = {**searchParams, **filterParams}
 
